@@ -9,8 +9,8 @@
 ## EXTRACT MODEL ###
 setMethod("semPlotModel_S4",signature("lavaan"),function(object){
 
-  if (class(object)=="blavaan") class(object) <- 'lavaan'
-  if (class(object)!="lavaan") stop("Input must me a 'lavaan' object")
+  if (is(object,"blavaan")) class(object) <- 'lavaan'
+  if (!is(object,"lavaan")) stop("Input must me a 'lavaan' object")
 
   
   # Extract parameter estimates:
